@@ -11,6 +11,6 @@ def main():
 
 @main.command(help='List available feature flags')
 @click.option('--feature-set', default='outcome.utils:feature_set')
-def features(feature_set):
+def features(feature_set: str):
     fs = load_obj(feature_set, default_obj='feature_set')
     fs.display_features()
