@@ -25,7 +25,7 @@ class FeatureType(Enum):
 _feature_pattern = r'^[a-z]+(_?[a-z]+_?[a-z])*$'
 _feature_prefix = 'WITH_FEAT_'
 
-_features: Dict[str, Union[bool, str]]
+_features: Dict[str, Union[bool, str, None]]
 _feature_types: Dict[str, FeatureType]
 _config: Config
 
@@ -49,7 +49,7 @@ def _feature_to_config_key(feature: str) -> str:
     return f'{_feature_prefix}{replaced}'
 
 
-def _coerce_boolean(v):
+def _coerce_boolean(v: object) -> bool:
     return str(v).lower() in {'yes', 'y', 'true', 't', '1'}
 
 
@@ -58,7 +58,9 @@ def set_config(config: Config):
     _config = config  # noqa: WPS122,WPS442
 
 
-def register_feature(feature: str, default: Optional[bool] = None, feature_type: FeatureType = FeatureType.boolean) -> None:
+def register_feature(
+    feature: str, default: Optional[Union[bool, str]] = None, feature_type: FeatureType = FeatureType.boolean,
+) -> None:
     if not _is_valid_feature_name(feature):
         raise FeatureException(f'Invalid feature name: {feature}')
 
@@ -90,7 +92,7 @@ def display_features():  # pragma: no cover
     table.add_column('Config Key', justify='left')
     table.add_column('Set By', justify='right')
 
-    def state_repr(state):
+    def state_repr(state: Union[str, bool, None]):
         return '[bold green]active[/bold green]' if state else '[bold red]inactive[/bold red]'
 
     def type_repr(feature_type: FeatureType):
@@ -116,19 +118,31 @@ def is_active(feature: str) -> bool:
     value = _feature_status_from_config(feature)
 
     if value is not None:
-        return value
+        return bool(value)
+
+    return bool(_features[feature])
+
+
+def value(feature: str) -> Optional[Union[str, bool]]:
+    if not _feature_check(feature):
+        return None
+
+    val = _feature_status_from_config(feature)
+
+    if val is not None:
+        return val
 
     return _features[feature]
 
 
-def _feature_status_from_config(feature: str) -> Optional[bool]:
+def _feature_status_from_config(feature: str) -> Optional[Union[str, bool]]:
     try:
         feature_key = _feature_to_config_key(feature)
-        value = _config.get(feature_key)
+        val = _config.get(feature_key)
 
         if _feature_types[feature] == FeatureType.boolean:
-            return value if isinstance(value, bool) else _coerce_boolean(value)
-        return value
+            return val if isinstance(val, bool) else _coerce_boolean(val)
+        return str(val)
 
     except KeyError:
         return None
@@ -137,14 +151,14 @@ def _feature_status_from_config(feature: str) -> Optional[bool]:
 def _feature_state_source(feature: str) -> StateSource:
     _feature_check(feature)
 
-    value = _feature_status_from_config(feature)
+    val = _feature_status_from_config(feature)
 
-    if value is None:
+    if val is None:
         return 'default'
     return 'config'
 
 
-def _feature_check(feature):
+def _feature_check(feature: str):
     if feature not in _features:
         if env.is_dev():
             warnings.warn(
