@@ -4,7 +4,7 @@ import re
 from typing import Pattern
 
 
-def regex_replace(input_value: str, pattern: Pattern, replacement: str) -> str:
+def regex_replace(input_value: str, pattern: Pattern[str], replacement: str) -> str:
     """Applies a regex replace using the pattern on the input string.
 
     Args:
